<?php
/**
* Client Section options
*
* @package Graduate_Pro
* @since Graduate Pro 1.0
*/

// Add Client Section enable section
$wp_customize->add_section( 'graduate_pro_client_section', array(
	'title'             => esc_html__( 'Client Section','graduate-pro' ),
	'description'		=> esc_html__( 'Client Section Options', 'graduate-pro' ),
	'panel'             => 'graduate_pro_section_options_panel'
) );

// Add Client Section enable setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[client_section_enable]', array(
	'default'           => $options['client_section_enable'],
	'sanitize_callback' => 'graduate_pro_sanitize_select'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[client_section_enable]', array(
	'label'             => esc_html__( 'Enable on', 'graduate-pro' ),
	'section'           => 'graduate_pro_client_section',
	'type'              => 'select',
	'choices'           => graduate_pro_enable_disable_options()
) );

// Add Client Section controller setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[client_section_controller]', array(
	'default'           => $options['client_section_controller'],
	'sanitize_callback' => 'graduate_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[client_section_controller]', array(
	'label'             => esc_html__( 'Enable Arrow Controls', 'graduate-pro' ),
	'section'           => 'graduate_pro_client_section',
	'type'              => 'checkbox',
	'active_callback' 	=> 'graduate_pro_is_client_section_active',
) );

// Add Client Section pager setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[client_section_pager]', array(
	'default'           => $options['client_section_pager'],
	'sanitize_callback' => 'graduate_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[client_section_pager]', array(
	'label'             => esc_html__( 'Enable Pager Controls', 'graduate-pro' ),
	'section'           => 'graduate_pro_client_section',
	'type'              => 'checkbox',
	'active_callback' 	=> 'graduate_pro_is_client_section_active',
) );

// Add Client Section draggable setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[client_section_draggable]', array(
	'default'           => $options['client_section_draggable'],
	'sanitize_callback' => 'graduate_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[client_section_draggable]', array(
	'label'             => esc_html__( 'Slider Draggable', 'graduate-pro' ),
	'section'           => 'graduate_pro_client_section',
	'type'              => 'checkbox',
	'active_callback' 	=> 'graduate_pro_is_client_section_active',
) );

// Add Client Section infinite loop setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[client_section_infinite_loop]', array(
	'default'           => $options['client_section_infinite_loop'],
	'sanitize_callback' => 'graduate_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[client_section_infinite_loop]', array(
	'label'             => esc_html__( 'Auto Play', 'graduate-pro' ),
	'section'           => 'graduate_pro_client_section',
	'type'              => 'checkbox',
	'active_callback' 	=> 'graduate_pro_is_client_section_active',
) );

// Add Client Section autoplay setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[client_section_autoplay]', array(
	'default'           => $options['client_section_autoplay'],
	'sanitize_callback' => 'graduate_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[client_section_autoplay]', array(
	'label'             => esc_html__( 'Infinite Loop', 'graduate-pro' ),
	'section'           => 'graduate_pro_client_section',
	'type'              => 'checkbox',
	'active_callback' 	=> 'graduate_pro_is_client_section_active',
) );

// Add Client Section no of visible slides setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[client_section_visible_slides]', array(
	'default'           => $options['client_section_visible_slides'],
	'sanitize_callback' => 'graduate_pro_sanitize_select'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[client_section_visible_slides]', array(
	'label'             => esc_html__( 'No of Visible Slides', 'graduate-pro' ),
	'section'           => 'graduate_pro_client_section',
	'type'              => 'select',
	'choices'           => array(
			5	=> esc_html__( '5 Slides', 'graduate-pro' ),
			6	=> esc_html__( '6 Slides', 'graduate-pro' ),
			7	=> esc_html__( '7 Slides', 'graduate-pro' )
		),
	'active_callback' 	=> 'graduate_pro_is_client_section_active',
) );

// Add Client Section type setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[client_section_content_type]', array(
	'default'           => $options['client_section_content_type'],
	'sanitize_callback' => 'graduate_pro_sanitize_select'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[client_section_content_type]', array(
	'label'           	=> esc_html__( 'Content Type', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_client_section',
	'type'            	=> 'select',
	'active_callback' 	=> 'graduate_pro_is_client_section_active',
	'choices'         	=> graduate_pro_client_content_type()
) );

// Add Client Section Count.
$wp_customize->add_setting( 'graduate_pro_theme_options[client_section_count]', array(
	'default'           => $options['client_section_count'],
	'sanitize_callback' => 'graduate_pro_sanitize_number_range',
	'validate_callback'	=> 'graduate_pro_validate_client_section_count'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[client_section_count]', array(
	'label'           	=> esc_html__( 'No of Clients', 'graduate-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 15. Please input the valid number and save. Then referesh the page to see the change.', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_client_section',
	'type'            	=> 'number',
	'active_callback' 	=> 'graduate_pro_is_client_section_not_demo',
	'input_attrs'		=> array(
		'max'	=> 15,
		'min'	=> 1,
		'style'	=> 'width:100px'
		)
) );

for( $i = 1; $i <= $options['client_section_count']; $i++ ) {

	// page content type setting and control.
	$wp_customize->add_setting( 'graduate_pro_theme_options[client_section_page_'. $i .']', array(
		'sanitize_callback' => 'graduate_pro_sanitize_page'
	) );

	$wp_customize->add_control( 'graduate_pro_theme_options[client_section_page_'. $i .']', array(
		'label'           	=> sprintf( esc_html__( 'Select Page %d', 'graduate-pro' ), $i ),
		'section'         	=> 'graduate_pro_client_section',
		'type'            	=> 'dropdown-pages',
		'active_callback' 	=> 'graduate_pro_is_client_section_page_active',
	) );

	// custom content type hr setting and control
	$wp_customize->add_setting( 'graduate_pro_theme_options[client_section_hr_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new graduate_Pro_Customize_Horizontal_Line( $wp_customize, 'graduate_pro_theme_options[client_section_hr_'.$i.']',
		array(
			'section'         => 'graduate_pro_client_section',
			'active_callback' => 'graduate_pro_is_client_section_custom_active',
			'type'			  => 'hr'
	) ) );

	// custom content type image setting and control
	$wp_customize->add_setting( 'graduate_pro_theme_options[client_section_image_'. $i .']',
	  array(
	    'sanitize_callback' 	=> 'graduate_pro_sanitize_image',
	  )
	);
	$wp_customize->add_control(
	  new WP_Customize_Image_Control( $wp_customize, 'graduate_pro_theme_options[client_section_image_'. $i .']',
	    array(
	    	'label'       		=> sprintf( esc_html__( 'Select Image %d', 'graduate-pro' ), $i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'graduate-pro' ), 110, 110 ),
			'section'     		=> 'graduate_pro_client_section',
			'active_callback'	=> 'graduate_pro_is_client_section_custom_active',
	    )
	  )
	);

	// custom content type alt setting and control
	$wp_customize->add_setting( 'graduate_pro_theme_options[client_section_url_'. $i .']', array(
		'sanitize_callback' => 'esc_url_raw'
	) );

	$wp_customize->add_control( 'graduate_pro_theme_options[client_section_url_'. $i .']', array(
		'label'           	=> esc_html__( 'Link for image', 'graduate-pro' ),
		'section'         	=> 'graduate_pro_client_section',
		'type'            	=> 'url',
		'active_callback' 	=> 'graduate_pro_is_client_section_custom_active',
	) );

	// custom content type alt setting and control
	$wp_customize->add_setting( 'graduate_pro_theme_options[client_section_alt_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( 'graduate_pro_theme_options[client_section_alt_'. $i .']', array(
		'label'           	=> esc_html__( 'Alternate text for image', 'graduate-pro' ),
		'section'         	=> 'graduate_pro_client_section',
		'type'            	=> 'text',
		'active_callback' 	=> 'graduate_pro_is_client_section_custom_active',
	) );
}