<?php
/**
 * Information Section
 *
 * This is the template for the content of Information Section
 *
 * @package Graduate_Pro
 * @since Graduate Pro 1.0
 */
if ( ! function_exists( 'graduate_pro_add_information_section' ) ) :
    /**
    * Add Information Section
    *
    *@since Graduate Pro 1.0
    */
    function graduate_pro_add_information_section() {

    // Check if information_section is enabled on frontpage
    $information_section_enable = apply_filters( 'graduate_pro_section_status', true, 'information_section_enable' );
    if ( true !== $information_section_enable ) {
      return false;
    }

    // Get Information Section details
    $section_details = array();
    $section_details = apply_filters( 'graduate_pro_filter_information_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render Information Section now.
    graduate_pro_render_information_section( $section_details );
    }
endif;
add_action( 'graduate_pro_primary_content', 'graduate_pro_add_information_section', 30 );


if ( ! function_exists( 'graduate_pro_get_information_section_details' ) ) :
  /**
   * Information Section details.
   *
   * @since Graduate Pro 1.0
   * @param array $input Information Section details.
   */
  function graduate_pro_get_information_section_details( $input ) {
    $options = graduate_pro_get_theme_options();

    // information_section type
    $information_section_content_type  = $options['information_section_content_type'];

    $content = array();
    switch ( $information_section_content_type ) {
        case 'demo':
            $images = array( 'universities', 'courses', 'counselors' );
            $title = array( esc_html__( 'Universities', 'graduate-pro' ), esc_html__( 'Courses', 'graduate-pro' ), esc_html__( 'Councelors', 'graduate-pro' ) );
            for ( $i = 0; $i <= 2; $i++ ) {
                $content[$i]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/'. $images[$i] .'.jpg';
                $content[$i]['url']          = '#';
                $content[$i]['title']        = $title[$i];
                $content[$i]['alt']          = esc_attr__( 'Information Section Image', 'graduate-pro' );
            }
        break;

        case 'page':
            $ids = array();

            for ( $i = 1; $i <= $options['information_section_column']; $i++ ) {
                $id = null;
                if ( isset( $options[ 'information_section_page_'.$i ] ) ) {
                    $id = $options[ 'information_section_page_'.$i ];
                }
                if ( ! empty( $id ) ) {
                    $ids[] = absint( $id );
                }
            }

            // Bail if no valid pages are selected.
            if ( empty( $ids ) ) {
                return $input;
            }

            $args = array(
                'no_found_rows'  => true,
                'orderby'        => 'post__in',
                'post_type'      => 'page',
                'post__in'       => $ids,
            );
        break;

        case 'post':
            $ids = array();

            for ( $i = 1; $i <= $options['information_section_column']; $i++ ) {
                $id = null;
                if ( isset( $options[ 'information_section_post_'.$i ] ) ) {
                    $id = $options[ 'information_section_post_'.$i ];
                }
                if ( ! empty( $id ) ) {
                    $ids[] = absint( $id );
                }
            }

            // Bail if no valid pages are selected.
            if ( empty( $ids ) ) {
                return $input;
            }

            $args = array(
                'no_found_rows'  => true,
                'orderby'        => 'post__in',
                'post_type'      => 'post',
                'post__in'       => $ids,
            );
        break;

        case 'category':
            $cat_id = '';
            if ( !empty( $options['information_section_category'] ) ) {
                $cat_id = $options['information_section_category'];
            }

            // Bail if no valid pages are selected.
            if ( empty( $cat_id ) ) {
                return $input;
            }else{
                $cat_id = absint( $cat_id );
            }

            $args = array(
                'no_found_rows'  => true,
                'cat'            => $cat_id,
                'post_type'      => 'post',
                'posts_per_page' => absint( $options['information_section_column'] ),
                'orderby'        => 'ASC',
            );
        break;

        case 'cat-list':
            $ids = array();

            for ( $i = 1; $i <= $options['information_section_column']; $i++ ) {
                $id = null;
                if ( isset( $options[ 'information_section_category_list_'.$i ] ) ) {
                    $id = $options[ 'information_section_category_list_'.$i ];
                }
                if ( ! empty( $id ) ) {
                    $ids[$i] = absint( $id );
                }
            }

            // Bail if no valid pages are selected.
            if ( empty( $ids ) ) {
                return $input;
            }

            $i = 1;
            foreach ( $ids as $cat_list ) {
                $cat_id     = $ids[$i];
                $category   = get_category( $cat_id );

                $content[$i]['url']             = get_category_link( $cat_id );
                $content[$i]['title']           = $category->name;
                $content[$i]['alt']             = ! empty( $options['information_section_image_alt_'. $i] ) ? $options['information_section_image_alt_'. $i] : $category->name;
                $content[$i]['img_array'][0]    = ! empty( $options['information_section_image_'. $i] ) ? $options['information_section_image_'. $i] : get_template_directory_uri().'/assets/uploads/no-featured-image-400x600.jpg';
                $i++;
            }
        break;

      default:
      break;
    }

    if ( 'demo' != $information_section_content_type && 'cat-list' != $information_section_content_type ) {
        // Fetch posts.
        $posts = get_posts( $args );

        if ( ! empty( $posts ) ) {
            $i = 1;
            foreach ( $posts as $key => $post ) {

                $page_id = $post->ID;
                $img_array = null;
                if ( has_post_thumbnail( $page_id ) ) {
                    $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'full' );
                } else {
                    $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-400x600.jpg';
                }

                if ( isset( $img_array ) ) {
                    $content[$i]['img_array'] = $img_array;
                }

                $content[$i]['url']      = get_permalink( $page_id );
                $content[$i]['title']    = get_the_title( $page_id );
                $content[$i]['alt']      = get_the_title( $page_id );

                $i++;
            }
            wp_reset_postdata();
        }
    }

    if ( ! empty( $content ) ) {
        $input = $content;
    }
    return $input;
}
endif;
// Information Section content details.
add_filter( 'graduate_pro_filter_information_section_details', 'graduate_pro_get_information_section_details' );


if ( ! function_exists( 'graduate_pro_render_information_section' ) ) :
    /**
    * Start Information Section
    *
    * @return string information_section content
    * @since Graduate Pro 1.0
    *
    */
    function graduate_pro_render_information_section( $content_details = array() ) {
        $options    = graduate_pro_get_theme_options();
        $column     = ( $options['information_section_column'] == 3 ) ? 'three-columns' : 'four-columns';

        if ( empty( $content_details ) ) {
          return;
        } ?>

        <section id="information-section" class="<?php echo $column; ?>">
            <div class="container">
                <div class="row">
                    <?php foreach( $content_details as $content_detail ) : ?>
                    <div class="column-wrapper wow fadeIn" data-wow-delay="0.1s" data-wow-duration="0.3s">
                        <a href="<?php echo esc_url( $content_detail['url'] ); ?>"><img src="<?php echo esc_url( $content_detail['img_array'][0] ); ?>" alt="<?php echo esc_attr( $content_detail['alt'] ); ?>">
                        <div class="black-overlay"></div></a>
                        <div class="information-content wow fadeInUp" data-wow-delay="0.2s" data-wow-duration="0.3s">
                            <div class="seperator"></div>
                            <h2><a href="<?php echo esc_url( $content_detail['url'] ); ?>" class="color-white"><?php echo esc_html( $content_detail['title'] ); ?></a></h2>
                        </div><!--.information-->
                    </div><!--.column-wrapper-->
                    <?php endforeach; ?>
                </div><!--.row-->
            </div><!--.container-->
        </section><!-- #information-section -->

<?php 
    }
endif;