<?php
/**
 * team_section section
 *
 * This is the template for the content of team_section section
 *
 * @package Graduate_Pro
 * @since Graduate Pro 1.0
 */
if ( ! function_exists( 'graduate_pro_add_team_section_section' ) ) :
  /**
   * Add team_section section
   *
   *@since Graduate Pro 1.0
   */
  function graduate_pro_add_team_section_section() {

    // Check if team_section is enabled on frontpage
    $team_section_enable = apply_filters( 'graduate_pro_section_status', true, 'team_section_enable' );
    if ( true !== $team_section_enable ) {
      return false;
    }

    // Get team_section section details
    $section_details = array();
    $section_details = apply_filters( 'graduate_pro_filter_team_section_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render team_section section now.
    graduate_pro_render_team_section_section( $section_details );
  }
endif;
add_action( 'graduate_pro_primary_content', 'graduate_pro_add_team_section_section', 60 );


if ( ! function_exists( 'graduate_pro_get_team_section_section_details' ) ) :
  /**
   * team_section section details.
   *
   * @since Graduate Pro 1.0
   * @param array $input team_section section details.
   */
  function graduate_pro_get_team_section_section_details( $input ) {
    $options = graduate_pro_get_theme_options();

    // team_section type
    $team_section_type  = $options['team_section_content_type'];

    $content = array();
    switch ( $team_section_type ) {
        case 'demo':
            
            for( $i = 1; $i <= 15; $i++ ) {
                if( $i <= 9 ) 
                    $count = '0'.$i;
                else
                    $count = $i;

                $content[$i]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/staff-' . $count . '.jpg';
                $content[$i]['url']          = '#';
                $content[$i]['title']        = sprintf( esc_html__( 'Meet Counselor %s', 'graduate-pro' ), $i );
                $content[$i]['excerpt']      = esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisc ing elit. Donec a neque interdum diam dapibus tincidunt. In euismod risus nec pellentesque egestas.', 'graduate-pro' );
                $content[$i]['alt']          = esc_attr__( 'Team Section Image', 'graduate-pro' );
            }
        break;

        case 'category':
            $cat_id = '';
            if ( !empty( $options['team_section_content_category'] ) ) {
                $cat_id = $options['team_section_content_category'];
            }

            // Bail if no valid pages are selected.
            if ( empty( $cat_id ) ) {
                return $input;
            }else{
                $cat_id = absint( $cat_id );
            }

            $args = array(
                'no_found_rows'  => true,
                'cat'            => $cat_id,
                'post_type'      => 'post',
                'posts_per_page' => absint( $options['team_section_count'] ),
            );
        break;

        default:
            $cat_id = '';
            if ( !empty( $options['team_section_'. $team_section_type ] ) ) {
                $cat_id = $options['team_section_'. $team_section_type ];
            }
            // Bail if no valid pages are selected.
            if ( empty( $cat_id ) ) {
                return $input;
            }else{
                $cat_id = absint( $cat_id );
            }

            $term = get_term_by('id', $cat_id , $team_section_type );
            $post_type = get_taxonomy( $term->taxonomy )->object_type[0];

            $args = array(
                'post_type'         => $post_type,
                'posts_per_page'    => absint( $options['team_section_count'] ),
                'tax_query'         => array(
                    array(
                        'taxonomy'  => $team_section_type,
                        'field'     => 'id',
                        'terms'     => $cat_id
                    )
                )
            );
        break;
    }

    if ( 'demo' != $team_section_type ) {
      // Fetch posts.
      $posts = get_posts( $args );

      if ( ! empty( $posts ) ) {

          $i = 1;
          foreach ( $posts as $key => $post ) {
              $page_id = $post->ID;
              $img_array = null;
            if ( has_post_thumbnail( $page_id ) ) {
                $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'post-thumbnail' );
            } else {
                $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-200x200.jpg';
            }

            if ( isset( $img_array ) ) {
              $content[$i]['img_array'] = $img_array;
            }

            $content[$i]['url']      = get_permalink( $page_id );
            $content[$i]['title']    = get_the_title( $page_id );
            $content[$i]['excerpt']  = graduate_pro_trim_content( 25, $post  );;
            $content[$i]['alt']      = get_the_title( $page_id );

            $i++;
          }
          wp_reset_postdata();
      }
    }

    if ( ! empty( $content ) ) {
      $input = $content;
    }
    return $input;
  }
endif;
// team_section section content details.
add_filter( 'graduate_pro_filter_team_section_section_details', 'graduate_pro_get_team_section_section_details' );


if ( ! function_exists( 'graduate_pro_render_team_section_section' ) ) :
  /**
   * Start team_section section
   *
   * @return string team_section content
   * @since Graduate Pro 1.0
   *
   */
   function graduate_pro_render_team_section_section( $content_details = array() ) {
        $options  = graduate_pro_get_theme_options();
        $content_type   = $options['team_section_content_type'];
        $category_link  = '#';
        if ( $content_type == 'category' ) {
            $category_link  = get_category_link( $options['team_section_content_category'] );
            $cat_name       = get_the_category_by_ID( $options['team_section_content_category'] );
        } elseif ( $content_type != 'category' && $content_type != 'demo' ) {
            $category_link  = get_term_link( $options['team_section_'. $content_type ], $content_type );
            $term           = get_term_by('id', $options['team_section_'. $content_type ] , $content_type );
            $cat_name       = $term->name;
        }

        if ( empty( $content_details ) ) {
          return;
        } ?>

        <section id="client-testimonial" class="page-section no-padding-top">
            <div class="container">
                <div class="row two-columns">
                    <div class="column-wrapper">
                        <?php 
                        $i = 1;
                        foreach( $content_details as $content_detail ) : ?>
                            <div id="tab-<?php echo $i; ?>" class="featured-image <?php echo ( $i == 1 ) ? 'active' : ''; ?>">
                                <img src="<?php echo esc_url( $content_detail['img_array'][0] ); ?>" alt="<?php echo esc_attr( $content_detail['alt'] ); ?>" class="wp-post-image">
                                <div class="blue-overlay"></div>
                                <div class="entry-container">
                                    <header class="entry-header">
                                        <h2 class="entry-title color-white"><?php echo esc_html( $content_detail['title'] ); ?></h2>
                                    </header>

                                    <div class="entry-content">
                                        <p><?php echo esc_attr( $content_detail['excerpt'] ); ?></p>
                                        <a href="<?php echo esc_url( $category_link ); ?>" class="view-more">
                                            <?php esc_html_e( 'VIEW ALL ', 'graduate-pro' );
                                            echo ! empty( $cat_name ) ? esc_html( $cat_name ) : esc_html__( 'Demo', 'graduate-pro' ); ?>
                                        </a>
                                    </div><!-- .entry-content -->
                                </div><!-- .entry-container -->
                            </div><!-- .featured-image -->
                        <?php 
                        $i++;
                        endforeach; ?>
                    </div><!-- .column-wrapper-->
                    <div class="column-wrapper">
                        <ul class="staff-list columns-5">
                            <?php 
                            $i = 1;
                            foreach( $content_details as $content_detail ) : ?>
                                <li data-tab="tab-<?php echo $i; ?>" <?php echo ( $i == 1 ) ? 'class="active"' : ''; ?>>
                                    <a href="<?php echo esc_url( $content_detail['url'] ); ?>">
                                        <img src="<?php echo esc_url( $content_detail['img_array'][0] ); ?>" alt="<?php echo esc_attr( $content_detail['alt'] ); ?>">
                                    </a>
                                </li>
                            <?php 
                            $i++;
                            endforeach; ?>
                        </ul><!-- .staff-list -->
                    </div><!-- .column-wrapper-->  
                </div><!-- .two-columns -->
            </div><!-- .container -->
        </section><!-- #client-testimonial -->

<?php 
    }
endif;